@@ -1,5 +1,5 @@
 /*
- * @(#)dbdimp.h	51.1 97/02/26 12:08:08
+ * @(#)dbdimp.h	52.2 97/03/02 12:57:04
  *
  * $Derived-From: dbdimp.h,v 1.5 1995/06/22 00:37:04 timbo Archaic $
  *
@@ -90,15 +90,14 @@ struct imp_sth_st
 };
 
 extern void dbd_ix_debug _((int n, char *fmt, const char *arg));
-extern void dbd_ix_sqlcode _((imp_dbh_t *dbh));
 extern void dbd_ix_seterror _((ErrNum rc));
 
 extern void dbd_dr_init _((dbistate_t *dbistate));
 extern int dbd_ix_driver _((SV *drh));
 extern int dbd_dr_disconnectall _((imp_drh_t *));
 
-extern SV *dbd_db_FETCH _((imp_dbh_t *dbh, SV *keysv));
-extern int dbd_db_STORE _((imp_dbh_t *dbh, SV *keysv, SV *valuesv));
+extern SV *dbd_db_FETCH_attrib _((imp_dbh_t *dbh, SV *keysv));
+extern int dbd_db_STORE_attrib _((imp_dbh_t *dbh, SV *keysv, SV *valuesv));
 extern int dbd_db_begin _((imp_dbh_t *sth));
 extern int dbd_db_commit _((imp_dbh_t *sth));
 extern int dbd_db_connect _((imp_dbh_t *dbh, char *dbs, char *uid, char *pwd));
@@ -107,8 +106,9 @@ extern int dbd_db_rollback _((imp_dbh_t *sth));
 extern void dbd_db_destroy _((imp_dbh_t *dbh));
 
 extern AV *dbd_st_fetch _((imp_sth_t *sth));
-extern SV *dbd_st_FETCH _((SV *sth, SV *keysv));
-extern int dbd_st_STORE _((SV *sth, SV *keysv, SV *valuesv));
+extern SV *dbd_st_FETCH_attrib _((imp_sth_t *sth, SV *keysv));
+extern int dbd_ix_immediate _((imp_dbh_t *dbh, char *stmt));
+extern int dbd_st_STORE_attrib _((imp_sth_t *sth, SV *keysv, SV *valuesv));
 extern int dbd_st_bind_ph _((SV *sth, SV *param, SV *value, SV *attribs, int boolean, int len));
 extern int dbd_st_blob_read _((SV *sth, int field, long offset, long len, SV *destsv, int destoffset));
 extern int dbd_st_execute _((imp_sth_t *sth));
@@ -116,12 +116,13 @@ extern int dbd_st_finish _((imp_sth_t *sth));
 extern int dbd_st_prepare _((imp_sth_t *sth, char *statement, SV *attribs));
 extern int dbd_st_rows _((SV *sth));
 extern void dbd_st_destroy _((imp_sth_t *sth));
-extern int dbd_ix_immediate _((imp_dbh_t *dbh, char *stmt));
 
 extern int dbd_ix_setbindnum _((imp_sth_t *sth, int items));
 extern int dbd_ix_bindsv _((imp_sth_t *sth, int idx, SV *val));
 extern int dbd_ix_setconnection _((imp_dbh_t *imp_dbh));
 
+extern const char *dbd_ix_module(void);
+
 #if ESQLC_VERSION >= 600
 extern void dbd_ix_disconnect _((char *connection));
 extern Boolean dbd_ix_connect _((char *conn, char *dbase, char *user, char *pass));
